VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsAgent"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'   Copyright (c) 1999 by Microsoft Corporation
'
'   THE INFORMATION AND CODE PROVIDED HEREUNDER (COLLECTIVELY REFERRED TO
'   AS "SOFTWARE") IS PROVIDED AS IS WITHOUT WARRANTY OF ANY KIND, EITHER
'   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
'   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN
'   NO EVENT SHALL MICROSOFT CORPORATION OR ITS SUPPLIERS BE LIABLE FOR
'   ANY DAMAGES WHATSOEVER INCLUDING DIRECT, INDIRECT, INCIDENTAL,
'   CONSEQUENTIAL, LOSS OF BUSINESS PROFITS OR SPECIAL DAMAGES, EVEN IF
'   MICROSOFT CORPORATION OR ITS SUPPLIERS HAVE BEEN ADVISED OF THE
'   POSSIBILITY OF SUCH DAMAGES. SOME STATES DO NOT ALLOW THE EXCLUSION OR
'   LIMITATION OF LIABILITY FOR CONSEQUENTIAL OR INCIDENTAL DAMAGES SO THE
'   FOREGOING LIMITATION MAY NOT APPLY.
'
'   This software may be copied and distributed royalty-free subject to
'   the following conditions:
'
'   1. You must copy all software without modification and must include
'      all pages, if the software is distributed without inclusion in your
'      software product. If you are incorporating the software in
'      conjunction with and as a part of your software product which adds
'      substantial value, you may modify and include portions of the
'      software.
'
'   2. You must place all copyright notices and other protective
'      disclaimers and notices contained on the software on all copies of
'      the software and your software product.
'
'   3. Unless the software is incorporated in your software product which
'      adds substantial value, you may not distribute this software for
'      profit.
'
'   4. You may not use Microsoft's name, logo, or trademarks to market
'      your software product.
'
'   5. You agree to indemnify, hold harmless, and defend Microsoft and its
'      suppliers from and against any claims or lawsuits, including
'      attorneys' fees, that arise or result from the use or distribution
'      of your software product and any modifications to the software.

' declare object variable
Public WithEvents AgentCtl As Agent
Attribute AgentCtl.VB_VarHelpID = -1

' event handlers for request object completion events
Private Sub AgentCtl_RequestComplete(ByVal Request As Object)
    Select Case Request
        Case objRequest
            ' handles transition to next slide
            If iSlideToProcess = 0 Then
                ' handles when narrator is not suspended
                If Not bSuspended Then
                    bProcessAnother = ProcessLine()
                    ' handles two command parts of SLIDE line, multiple blank lines in script, blank line(s) following WAIT command, etc.
                    While bProcessAnother And Not bSuspended
                        bProcessAnother = ProcessLine()
                    Wend
                End If
            Else
                ' check if not suspended before going to next slide
                If Not bSuspended And objRequest.Status = 0 Then
                    ActivePresentation.SlideShowWindow.View.GotoSlide iSlideToProcess
                    ProcessNotesPage
                End If
            End If
        Case Else
    End Select
End Sub

' event handlers for request object start events
Private Sub AgentCtl_RequestStart(ByVal Request As Object)
    ' iterates through each character (if loaded)
    ' *** to use more than six characters as narrators in your presentation, change the upper bound in the following line
    For i = 1 To 6
        If Not (objLoopRequest(i) Is Nothing) Then
            ' checks if Start event was for Looping animation
            If objLoopRequest(i) = Request Then
                ' loop for duration then stop looping animation
                TimerLoop iLoopDuration(i)
                Narrator(i).Stop objLoopRequest(i)
                ' continue with next command line if not immediate execute mode
                If bLoopContinue(i) = True Then
                    bProcessAnother = ProcessLine()
                End If
                Exit For
            End If
        End If
    Next
End Sub

' event handlers for character Hide events
Private Sub AgentCtl_Hide(ByVal CharacterID As String, ByVal Cause As Integer)
    ' end narration if user selects Hide from context menu of narrator
    If Not bScriptedHide Then
        ' iterates through each character (if loaded) and hides
        ' *** to use more than six characters as narrators in your presentation, change the upper bound in the following line
        For i = 1 To 6
            If Not (Narrator(i) Is Nothing) Then
                If Narrator(i).Visible Then
                    Narrator(i).StopAll
                    Narrator(i).Hide
                End If
            End If
        Next
        ' delay for the Hide animations to finish playing before ending execution
        TimerLoop 6
        End
    ' scripted Hide command (but not an End command)
    Else
        ' continue to process another command line
        bProcessAnother = True
        ' reset variable so user can interrupt a character
        bScriptedHide = False
    End If
End Sub

' event handlers for when user makes selection from narrator context menu
Private Sub AgentCtl_Command(ByVal UserInput As Object)
    Select Case UserInput.Name
        ' user selects Suspend from character context menu to halt narration
        Case "Suspend"
            Narrator(iCharacter).Stop objRequest
            bSuspended = True
            ' reset context menu items
            SetSuspendedMenu
        ' user selects Resume from character context menu to continue narration
        Case "Resume"
            ' check if still on same slide to resume from
            If iResumeSlide = ActivePresentation.SlideShowWindow.View.Slide.SlideIndex Then
                ' narration already finished for this slide,
                If Len(Mid(strScript, iCurrentPos)) = 0 Then
                    ' don't have another slide to go to
                    If iSlideToProcess = 0 Then
                        Narrator(iCharacter).Play ("Confused")
                        Narrator(iCharacter).Speak "Er, I've already finished narrating everything on this slide."
                        Narrator(iCharacter).Play ("RestPose")
                        Narrator(iCharacter).Speak "Why don't you go to another slide for me to resume from?"
                        ' reset variables so narration for this slide can be repeated anyway
                        iResumePos = 1
                        iCurrentPos = 1
                    ' go to next slide and resume
                    Else
                        bSuspended = False
                        ' reset context menu items
                        SetResumedMenu
                        Narrator(iCharacter).Play ("Think")
                        Narrator(iCharacter).Speak "Ok, let me continue..."
                        ActivePresentation.SlideShowWindow.View.GotoSlide iSlideToProcess
                        ProcessNotesPage
                    End If
                ' else resume processing rest of script
                Else
                    bSuspended = False
                    ' reset context menu items
                    SetResumedMenu
                    ' if suspended by user resume from last line
                    If Mid(LTrim(Mid(strScript, iResumePos)), 1, 7) <> "SUSPEND" Then
                        iCurrentPos = iResumePos
                    End If
                    Narrator(iCharacter).Play ("Think")
                    If iCurrentPos = 1 Then
                        Narrator(iCharacter).Speak "Ok, let me begin over again."
                    Else
                        Narrator(iCharacter).Speak "Let's see now, where was I?"
                    End If
                    Narrator(iCharacter).Play ("RestPose")
                    bProcessAnother = ProcessLine()
                End If
            ' else resume the presentation from current (different) slide
            Else
                bSuspended = False
                ' reset context menu items
                SetResumedMenu
                Narrator(iCharacter).Play ("Think")
                Narrator(iCharacter).Speak "Let's see, where am I now?"
                Narrator(iCharacter).Play ("RestPose")
                iSlideToProcess = ActivePresentation.SlideShowWindow.View.Slide.SlideIndex
                ProcessNotesPage
            End If
    End Select
End Sub

' event handlers for bookmark events in output text
Private Sub AgentCtl_Bookmark(ByVal BookmarkID As Long)
    ' this code doesn't actually do anything, you can code handlers for these bookmark events yourself
    ' NOTE: if your code for these are changing the contents of the slide, you may not want to save these changes
    Select Case iBookmark
        Case Else
    End Select
End Sub

